{ config, pkgs, ... }:
{
  # NixOS general:
  #   https://github.com/NixOS/nixpkgs/tree/nixos-23.11/pkgs/games/
  #   https://nixos.wiki/wiki/Games
  #   https://nixos.wiki/wiki/Minetest_Server
  #   https://nixos.wiki/wiki/Factorio (Multip Player Server)
  # General:
  #   https://wiki.archlinux.org/title/List_of_games
  #   https://en.wikipedia.org/wiki/List_of_open-source_video_games
  # Game Launchers:
  #   https://nixos.wiki/wiki/Steam
  #   https://nixos.wiki/wiki/Lutris
  # Non-packaged games:
  #   https://ya2.itch.io/yorg (Racing game)
  #   -> However, there is `itch` a laouncher for ithc.io games
  #   https://unknown-horizons.org/ (A 2D realtime strategy simulation with an emphasis on economy and city building.)
  #   https://github.com/mgerdes/Open-Golf

  users.users.yoda = {
    packages = with pkgs; [
      #
      # Sandbox
      #
      minetest # Infinite-world block sandbox game
      classicube # A lightweight, custom Minecraft Classic/ClassiCube client with optional additions written from scratch in C
      voxelands # Voxelands is a sandbox construction game based on Minetest
      airshipper # Provides automatic updates for the voxel RPG Veloren. https://www.veloren.net/

      #
      # Chess
      #
      gnome.gnome-chess # Play the classic two-player boardgame of chess
      gnuchess # GNU Chess engine. Can be used by gnome-chess.

      #
      # Mines
      #
      gnome.gnome-mines # Clear hidden mines from a minefield.
      libremines

      #
      # Arcade and puzzles
      #
      space-cadet-pinball # Reverse engineering of "3D Pinball for Windows – Space Cadet", a game bundled with Windows
      superTux # Classic 2D jump'n run sidescroller game
      mari0 # Crossover between Super Mario Bros. and Portal
      armagetronad # A multiplayer networked arcade racing game in 3D similar to Tron
      neverball # Tilt the floor to roll a ball
      gnujump # 2D jump game
      gnome.gnome-nibbles # Guide a worm around a maze
      gnome.gnome-taquin # Move tiles so that they reach their places
      gnome.gnome-tetravex # Complete the puzzle by matching numbered tiles
      gnugo # GNU Go - A computer go player

      #
      # Music
      #
      osu-lazer-bin # Dance and rythm game
      stepmania # Dance and rhythm game

      #
      # First Person Shooter
      #
      warsow # Multiplayer FPS game designed for competitive gaming. Similar to Unreal Tournament.
      sauerbraten # Cube 2: Sauerbraten. A multiplayer & singleplayer first person shooter, the successor of the Cube FPS
      assaultcube # Fast and fun first-person-shooter based on the Cube FPS
      xonotic # The Fast Arena Shooter
      #
      # Third Person / 2D Shooter
      #
      teeworlds # Retro multiplayer shooter game

      #
      # RPG
      #
      freedroidrpg # Similar to Diablo. 3D with fixed camera angle.

      #
      # Strategy
      #
      zeroadPackages.zeroad-unwrapped # 0 A.D. (pronounced “zero-ey-dee”) is a historical Real Time Strategy (RTS) game
      openra # OpenRA: recreates and modernizes classic real time strategy games, like Red Alert, Command & Conquer, and Dune 2000.
      unvanquished # A fast paced, first person strategy game
      megaglest # Real-time strategy (RTS) game. Screnshots: https://megaglest.org/media/
      wesnoth # The Battle for Wesnoth, a turn-based strategy game with a fantasy theme
      hedgewars # Turn-based strategy artillery game similar to Worms
      hase # Hase is a gravity based artillery shooter. It is similar to Worms, Hedgewars or artillery, but the gravity force and direction depends on the mass nearby. It is optimized for mobile game consoles like the GP2X, Open Pandora or GCW Zero, so it doesn't make use of the mouse even on the PC.

      #
      # Racing
      #
      stuntrally # Stunt Rally game with Track Editor, based on VDrift and OGRE. https://stuntrally.tuxfamily.org/
      superTuxKart # A 3D kart racing game
      extremetuxracer # High speed arctic racing game based on Tux Racer
      flightgear # Flight simulator

      #crossfire-client # GTKv2 client for the Crossfire free MMORPG. Screenshot: https://crossfire.real-time.com/images/clients/debian10-screenshot.png

      #
      # Purchase/Game files required
      #
      #fallout1-ce
      #fallout2-ce # A fully working re-implementation of Fallout 2, with the same original gameplay, engine bugfixes, and some quality of life improvements
      #openrw # Unofficial open source recreation of the classic Grand Theft Auto III game executable
    ];
  };
}
